==> unicharm-domain-0.0.4-sources.jar: com/xforceplus/unicharm/metadata/EntityMeta.java <==
package com.xforceplus.unicharm.metadata;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.xforceplus.ultraman.bocp.gen.typed.TypedField;


/**
* <p>
    * 
    * </p>
*
* @author ultraman
* @since 2021-06-30
*/

public class EntityMeta {

    public interface SellerInvoice {
        static Long id() {
            return 1409779755568013314L;
        }
        static String code() {
            return "sellerInvoice";
        }
        TypedField<String> INVOICECODE = new TypedField<>(String.class, "invoiceCode");
        TypedField<String> INVOICENO = new TypedField<>(String.class, "invoiceNo");
        TypedField<String> SALESBILLNO = new TypedField<>(String.class, "salesbillNo");
        TypedField<String> SALESBILLITEMNO = new TypedField<>(String.class, "salesbillItemNo");
        TypedField<String> ITEMNO = new TypedField<>(String.class, "itemNo");
        TypedField<LocalDateTime> PAPERDRAWDATE = new TypedField<>(LocalDateTime.class, "paperDrawDate");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> PURCHASERNAME = new TypedField<>(String.class, "purchaserName");
        TypedField<String> PURCHASERTAXNO = new TypedField<>(String.class, "purchaserTaxNo");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<String> EXT3 = new TypedField<>(String.class, "ext3");
        TypedField<String> EXT4 = new TypedField<>(String.class, "ext4");
        TypedField<String> EXT5 = new TypedField<>(String.class, "ext5");
    }

}

==> unicharm-domain-0.0.6-sources.jar: com/xforceplus/unicharm/metadata/EntityMeta.java <==
package com.xforceplus.unicharm.metadata;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.xforceplus.ultraman.bocp.gen.typed.TypedField;


/**
* <p>
    * 
    * </p>
*
* @author ultraman
* @since 2021-07-02
*/

public class EntityMeta {

    public interface SellerInvoice {
        static Long id() {
            return 1409779755568013314L;
        }
        static String code() {
            return "sellerInvoice";
        }
        TypedField<String> INVOICECODE = new TypedField<>(String.class, "invoiceCode");
        TypedField<String> INVOICENO = new TypedField<>(String.class, "invoiceNo");
        TypedField<String> SALESBILLNO = new TypedField<>(String.class, "salesbillNo");
        TypedField<String> SALESBILLITEMNO = new TypedField<>(String.class, "salesbillItemNo");
        TypedField<String> ITEMNO = new TypedField<>(String.class, "itemNo");
        TypedField<String> PAPERDRAWDATE = new TypedField<>(String.class, "paperDrawDate");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> PURCHASERNAME = new TypedField<>(String.class, "purchaserName");
        TypedField<String> PURCHASERTAXNO = new TypedField<>(String.class, "purchaserTaxNo");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<String> EXT3 = new TypedField<>(String.class, "ext3");
        TypedField<String> EXT4 = new TypedField<>(String.class, "ext4");
        TypedField<String> EXT5 = new TypedField<>(String.class, "ext5");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<LocalDateTime> PAPERDRAWTIME = new TypedField<>(LocalDateTime.class, "paperDrawTime");
    }

}
